## Documentation

All documentation for `sleepens` is located here!

[**pydoc**](https://github.com/paradoxysm/sleepens/tree/master/doc/pydoc) : Documentation regarding python classes and functions.

[**guides**](https://github.com/paradoxysm/sleepens/tree/master/doc/guides) : Guides on using `sleepens`.

## Overview

**Beep Beep!** Sorry, we're still under construction! Stay tuned...
